@@ -1199,8 +1199,8 @@ register struct tm *	timeptr;
 }
 
 char *
-_ctime(timep)
-time_t * timep;
+ctime(timep)
+const time_t *timep;
 {
 	return _asctime(_localtime(timep));
 }
@@ -1410,7 +1410,7 @@ Long		offset;
 }
 
 time_t
-_mktime(tmp)
+mktime(tmp)
 struct tm *tmp;
 {
 	return time1(tmp, localsub, 0L);
